@@ -4,3 +4,10 @@
 #' @author Bastiaan Quast \email{bquast@@gmail.com}
 #' @seealso http://qua.st/diagonals
 NULL
+.onAttach <- function(...) {
+  packageStartupMessage('
+D I
+A G
+    O N
+    A L
+        S')}
